<?php
/**
 * Plugin Name: DMG Privacy
 * Plugin URI: https://github.com/ANMedia/dmg-privacy-wp-plugin
 * Description: Embed the DMG Privacy Policy information via a WP Shortcode
 * Version: 1.0.2
 */

/**
 * A shortcode to output the privacy policy
 */
class DMG_Privacy_Shortcode {


	/**
	 * Setup the shortcode
	 *
	 * @return void
	 */
	public static function init() {
		add_shortcode( 'dmgprivacy', array( __CLASS__, 'shortcode' ) );
	}

	/**
	 * Add CSS and JS to power the modal
	 *
	 * @return void
	 */
	public static function add_scripts() {
		?>
<style>
#dmg-privacy-popup {
	top: 0;
	left: 0;
	align-content: center;
	padding: 1rem;
	position: fixed;
	width: 100%;
	height: 90vh;
	z-index: 2147483647;
}
#dmg-privacy-closeBtn {
	top: 0;
	background-color: #000;
	width: 100%;
	color: #fff;
	right: 0;
	text-align: right;
	cursor: pointer;
	padding: .5rem;
	font-size: 1rem;
}

#dmg-privacy-popup.dmg-privacy-hidden {
	display: none;
}

.dmg-privacy .optanon-show-settings-popup-wrapper {
    display: inline-block;
    height: 2em;
}
.dmg-privacy p, .dmg-privacy li {
	margin-bottom:1em;
}
.privacysection {
	padding:10px;
	color: #444;
	cursor: pointer;
	transition: 0.4s;
	margin: 0 0 10px;
    font-size: 1.3em;
}
.privacysection.active, .privacysection:hover {
	background-color: #ccc;
}

.privacypanel {
	padding: 0 18px;
	background-color: white;
	max-height: 0;
	overflow: hidden;
	transition: max-height 0.2s ease-out;
}
.privacypanel p {
    font-size:1em;
}
.privacypanel h3 {
    font-size:1.4em;
}
.privacypanel h4 {
    font-size:1.25em;
    font-weight: 700;
}
.privacypanel h5 {
    font-size:1.1em;
    font-weight: 600;
	margin: 0 0 2em 0;
}
.privacypanel h6 {
    font-size:1.1em;
}
</style>
<script type="text/javascript">

document.getElementById('dmg-privacy-submit').addEventListener('click', function(e) {
	e.preventDefault();
	document.getElementById('dmg-privacy-popup').classList.remove('dmg-privacy-hidden');
});
document.getElementById('dmg-privacy-closeBtn').addEventListener('click', function(e) {
	e.preventDefault();
	document.getElementById('dmg-privacy-popup').classList.add('dmg-privacy-hidden');
});

//Accordion setup
let i;
var accSection = document.getElementsByClassName("privacysection");

for (i = 0; i < accSection.length; i++) {
	accSection[i].addEventListener("click", function() {
		this.classList.toggle("active");

		/* Toggle between hiding and showing the active panel */
		let panel = this.nextElementSibling;
		if (panel.style.maxHeight) {
			panel.style.maxHeight = null;
		} else {
			panel.style.maxHeight = panel.scrollHeight + "px";
		}
	});
}
</script>
		<?php
	}

	/**
	 * Shortcode callback
	 *
	 * @param array $atts The shortcode attributes
	 * @return string The HTML markup to output
	 */
	public static function shortcode( $atts ) {
		$atts = shortcode_atts(
			array(
				'id'  => false,
				'url' => 'https://dmgmedia.co.uk/wp-json/wp/v2/privacy-policy/',
				'col' => '#efefef'
			),
			$atts
		);

		add_action( 'wp_footer', array( __CLASS__, 'add_scripts' ) );

		$markup = '<div class="dmg-privacy">';

		//Check for a hex color string 
		if(preg_match('/^#[a-f0-9]{6}$/i', $atts['col'])) //hex color is valid
		{
			$header_bg_color = $atts['col'];
		} elseif (preg_match('/^[a-f0-9]{6}$/i', $atts['col'])) //hex color without # is valid
		{
			$header_bg_color = '#' . $atts['col'];
		} else {
			$header_bg_color = '#efefef'; //hex color default
		}

		if ( empty( $atts['id'] ) ) {
			$markup .= '<!-- No ID Provided -->';
		} else {
			$cached_data = get_transient( 'dmgmedia_privacy' );
			if ( ! empty( $cached_data ) ) {
				$data = $cached_data;
			} else {
				$url      = $atts['url'] . $atts['id'];
				$response = wp_remote_get( $url );
				$body     = wp_remote_retrieve_body( $response );
				$data     = json_decode( $body );
			}
			if ( ! is_wp_error( $data ) && ! empty( $data ) ) {
				
				$policytitle = wp_kses_post( $data->title->rendered );
				$markup .= '<h1>' . $policytitle . '</h1>';
				$markup .= '<h2>Privacy & Cookies Policy (the “Policy”)</h2>';
				$policyupdated = wp_kses_post( $data->acf->last_updated );
				$markup .= '<h3>Last updated: ' . date("d F Y", strtotime($policyupdated)) . '</h3>';				
				$prevversion = wp_kses_post( $data->acf->previous_version );
				$markup .= '<h3>Previous version: ' . date("d F Y", strtotime($prevversion)) . '</h3>';				
				$policyintro = wp_kses_post( $data->acf->introduction );
				$policyintro = str_replace("\r\n\r\n", '</p><p>', $policyintro);
				$policyintro = str_replace("\n\n", '</p><p>', $policyintro);
				$markup .= '<p>' . $policyintro . '</p>';
				$policycookiesettings = wp_kses_post( $data->acf->cookie_settings );
				$policycookiesettings = str_replace("\r\n\r\n", '</p><p>', $policycookiesettings);
				$policycookiesettings = str_replace("\n\n", '</p><p>', $policycookiesettings);
				$markup .= '<p>' . $policycookiesettings . '</p>';

				$iframe_src = ( ! empty( $data->acf->dsr_form_url ) ) ? $data->acf->dsr_form_url : '';
				$popup_html = "<div id='dmg-privacy-popup' class='dmg-privacy-hidden'><div id='dmg-privacy-closeBtn'>Close</div><iframe src='$iframe_src' height='100%' width='100%'></iframe></div>";
				$markup    .= $popup_html;

				$popup_button = "<a style='display:none;' href='$iframe_src' id='dmg-privacy-submit'>Submit Data Subject Request</a>";
				$markup      .= $popup_button;



				$privacy_markup = '<div class="privacyaccordion">';
				if ( ! empty( $data->acf->privacypolicy ) ) {
					foreach ( $data->acf->privacypolicy as $block ) {
						$title           = wp_kses_post( $block->tab_title );
						$privacy_markup .= "<h3 style='background-color:" . $header_bg_color . ";' class='privacysection'>$title</h3>";
						$content         = wp_kses_post( $block->tab_content );
						$content		 = wpautop( $content );
						
						$privacy_markup .= "<div class='privacypanel'>$content</div>";
					}
				}
				$privacy_markup .= '</div>';
				$markup .= $privacy_markup;
				set_transient( 'dmgmedia_privacy', $data, 3600 );
			} else {
				$markup .= "<!-- Error requesting $url -->";
			}
		}

		$markup .= '</div>';

		return $markup;

	}
}

DMG_Privacy_Shortcode::init();

